@@ -1,5 +1,6 @@
 #!/usr/bin/perl -W
 use HTML::Menu::TreeView qw(Tree css jscript style documentRoot preload);
+use CGI qw(-compile :all  -private_tempfiles);
 use strict;
 my @tree = (
             {image => "tar.png", onclick => "alert('onclick');", text => "onclick",},
@@ -13,23 +14,5 @@ my @tree = (
 );
 documentRoot("../httpdocs/");
 style("Crystal");
-
-print "Content-Type: text/html$/$/
-<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">
-<html>
-<head>
-<title>treeview  FO Syntax</title>
-<style type=\"text/css\">" . css() . "</style>
-<script language=\"JavaScript\" type=\"text/javascript\">
-//<!--
-
-" . jscript() . preload() . "
-
-//-->
-</script>
-</head>
-<body>
-<table align=\"left\" border=\"0\" cellpadding=\"0\" cellspacing=\"0\" summary=\"Table\"  ><tr><td>
-" . Tree(\@tree) . "</td></tr><tr><td>";
-print '</td></tr></table></body></html>';
+print header, start_html(-title => 'Columns', -script => jscript() . preload(), -style => {-code => css()}), Tree(\@tree), end_html;
 
